ply2atti
========

```
usage: ply2atti [-h] --file INFILE [--split] colors [colors ...]

Extract planes painted on stanford polygon (.ply) files on meshlab.

positional arguments:
  colors         Colors to be extracted

optional arguments:
  -h, --help     show this help message and exit
  --file INFILE  input painted 3d model
  --split        Split the resulting attitudes in one file per color
```
